import setuptools

setuptools.setup(
    name="unrealistic",
    version="0.0.11",
    author="Wit",
    author_email="airesntt@arisetn.seu",
    description="Nothing.",
    long_description="Nothing.",
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(),
    url="",
    #scripts=['probecard/bin/probecard'],
    install_requires=[
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
    ],
)
